from setuptools import setup

setup(name='rai_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['rai_distributions'],
      author = 'Santos Rai',
      zip_safe=False)
